@@ -1,3 +1,4 @@
+import ckan.logic as logic
 import ckan.model as model
 import ckan.plugins.toolkit as toolkit
 
@@ -33,8 +34,14 @@ def get_reference_dict(value):
 
 
 def get_user_name(user_id):
-    usr = toolkit.get_action('user_show')(data_dict={'id': user_id})
-    return usr["name"], usr["display_name"]
+    try:
+        usr = toolkit.get_action('user_show')(data_dict={'id': user_id})
+        name = usr["name"]
+        display_name = usr["display_name"] or usr["name"]
+    except logic.NotAuthorized:
+        name = user_id
+        display_name = ""  # do not display user
+    return name, display_name
 
 
 def get_valid_licenses(license_id):
@@ -44,13 +51,13 @@ def get_valid_licenses(license_id):
 
 
 def license_options(existing_license_id="none"):
-    '''Returns [(l.title, l.id), ...] for the licenses configured to be
+    """Returns [(l.title, l.id), ...] for the licenses configured to be
     offered. Always includes the existing_license_id, if supplied.
 
     DCOR edits:
      - prohibit license downgrade
      - still allow licenses not defined in LICENSE_RATING
-    '''
+    """
     register = model.Package.get_license_register()
     sorted_licenses = sorted(register.values(), key=lambda x: x.title)
     license_ids = [lic.id for lic in sorted_licenses]
