@@ -20,7 +20,8 @@ def patch_resource_noauth(package_id, resource_id, data_dict):
 
 def set_dc_config_job(resource):
     """Store all DC config metadata"""
-    if resource.get('mimetype') in DC_MIME_TYPES:
+    if (resource.get('mimetype') in DC_MIME_TYPES
+            and resource.get("dc:setup:channel width", None) is None):
         path = get_resource_path(resource["id"])
         wait_for_resource(path)
         data_dict = {}
@@ -36,11 +37,16 @@ def set_dc_config_job(resource):
             package_id=resource["package_id"],
             resource_id=resource["id"],
             data_dict=data_dict)
+        return True
+    return False
 
 
 def set_format_job(resource):
     """Writes the correct format to the resource metadata"""
-    if resource.get('mimetype') in DC_MIME_TYPES:
+    mimetype = resource.get("mimetype")
+    rformat = resource.get("format")
+    if mimetype in DC_MIME_TYPES and rformat in [mimetype, None]:
+        # (if format is already something like RT-FDC then we don't do this)
         path = get_resource_path(resource["id"])
         wait_for_resource(path)
         with dclab.rtdc_dataset.check.IntegrityChecker(path) as ic:
@@ -48,10 +54,13 @@ def set_format_job(resource):
                 fmt = "RT-FDC"
             else:
                 fmt = "RT-DC"
-        patch_resource_noauth(
-            package_id=resource["package_id"],
-            resource_id=resource["id"],
-            data_dict={"format": fmt})
+        if rformat != fmt:  # only update if necessary
+            patch_resource_noauth(
+                package_id=resource["package_id"],
+                resource_id=resource["id"],
+                data_dict={"format": fmt})
+            return True
+    return False
 
 
 def set_sha256_job(resource):
@@ -72,3 +81,5 @@ def set_sha256_job(resource):
             package_id=resource["package_id"],
             resource_id=resource["id"],
             data_dict={"sha256": sha256sum})
+        return True
+    return False
