@@ -36,10 +36,8 @@ def synchronous_enqueue_job(job_func, args=None, kwargs=None, title=None,
     job_func(*args, **kwargs)
 
 
-# We need the dcor_depot extension to make sure that the symbolic-
-# linking pipeline is used.
-@pytest.mark.ckan_config('ckan.plugins', 'dcor_schemas dcor_depot')
-@pytest.mark.usefixtures('clean_db', 'with_request_context')
+@pytest.mark.ckan_config('ckan.plugins', 'dcor_schemas')
+@pytest.mark.usefixtures('clean_db', 'with_plugins', 'with_request_context')
 @mock.patch('ckan.plugins.toolkit.enqueue_job',
             side_effect=synchronous_enqueue_job)
 def test_set_dc_config_job_fl(enqueue_job_mock, create_with_upload,
@@ -54,9 +52,9 @@ def test_set_dc_config_job_fl(enqueue_job_mock, create_with_upload,
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context, owner_org, with_resource=False,
-                           activate=False)
+    create_context = {'ignore_auth': False,
+                      'user': user['name'], 'api_version': 3}
+    dataset = make_dataset(create_context, owner_org, activate=False)
     content = (data_dir / "calibration_beads_47.rtdc").read_bytes()
     result = create_with_upload(
         content, 'test.rtdc',
@@ -71,9 +69,7 @@ def test_set_dc_config_job_fl(enqueue_job_mock, create_with_upload,
     assert np.allclose(resource["dc:setup:flow rate"], 0.06)
 
 
-# We need the dcor_depot extension to make sure that the symbolic-
-# linking pipeline is used.
-@pytest.mark.ckan_config('ckan.plugins', 'dcor_schemas dcor_depot')
+@pytest.mark.ckan_config('ckan.plugins', 'dcor_schemas')
 @pytest.mark.usefixtures('clean_db', 'with_request_context')
 @mock.patch('ckan.plugins.toolkit.enqueue_job',
             side_effect=synchronous_enqueue_job)
@@ -89,9 +85,9 @@ def test_set_format_job(enqueue_job_mock, create_with_upload, monkeypatch,
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context, owner_org, with_resource=False,
-                           activate=False)
+    create_context = {'ignore_auth': False,
+                      'user': user['name'], 'api_version': 3}
+    dataset = make_dataset(create_context, owner_org, activate=False)
     path = data_dir / "calibration_beads_47.rtdc"
     # create dataset without fluorescence
     tmppath = pathlib.Path(tmpdir) / "calibratino_beads_nofl.rtdc"
@@ -109,9 +105,7 @@ def test_set_format_job(enqueue_job_mock, create_with_upload, monkeypatch,
     assert resource["format"] == "RT-DC"
 
 
-# We need the dcor_depot extension to make sure that the symbolic-
-# linking pipeline is used.
-@pytest.mark.ckan_config('ckan.plugins', 'dcor_schemas dcor_depot')
+@pytest.mark.ckan_config('ckan.plugins', 'dcor_schemas')
 @pytest.mark.usefixtures('clean_db', 'with_request_context')
 @mock.patch('ckan.plugins.toolkit.enqueue_job',
             side_effect=synchronous_enqueue_job)
@@ -127,9 +121,9 @@ def test_set_format_job_fl(enqueue_job_mock, create_with_upload, monkeypatch,
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context, owner_org, with_resource=False,
-                           activate=False)
+    create_context = {'ignore_auth': False,
+                      'user': user['name'], 'api_version': 3}
+    dataset = make_dataset(create_context, owner_org, activate=False)
     content = (data_dir / "calibration_beads_47.rtdc").read_bytes()
     result = create_with_upload(
         content, 'test.rtdc',
@@ -142,9 +136,7 @@ def test_set_format_job_fl(enqueue_job_mock, create_with_upload, monkeypatch,
     assert resource["format"] == "RT-FDC"
 
 
-# We need the dcor_depot extension to make sure that the symbolic-
-# linking pipeline is used.
-@pytest.mark.ckan_config('ckan.plugins', 'dcor_schemas dcor_depot')
+@pytest.mark.ckan_config('ckan.plugins', 'dcor_schemas')
 @pytest.mark.usefixtures('clean_db', 'with_request_context')
 @mock.patch('ckan.plugins.toolkit.enqueue_job',
             side_effect=synchronous_enqueue_job)
@@ -160,9 +152,9 @@ def test_set_sha256_job(enqueue_job_mock, create_with_upload, monkeypatch,
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context, owner_org, with_resource=False,
-                           activate=False)
+    create_context = {'ignore_auth': False,
+                      'user': user['name'], 'api_version': 3}
+    dataset = make_dataset(create_context, owner_org, activate=False)
     content = (data_dir / "calibration_beads_47.rtdc").read_bytes()
     result = create_with_upload(
         content, 'test.rtdc',
@@ -176,9 +168,7 @@ def test_set_sha256_job(enqueue_job_mock, create_with_upload, monkeypatch,
     assert resource["sha256"] == sha
 
 
-# We need the dcor_depot extension to make sure that the symbolic-
-# linking pipeline is used.
-@pytest.mark.ckan_config('ckan.plugins', 'dcor_schemas dcor_depot')
+@pytest.mark.ckan_config('ckan.plugins', 'dcor_schemas')
 @pytest.mark.usefixtures('clean_db', 'with_request_context')
 @mock.patch('ckan.plugins.toolkit.enqueue_job',
             side_effect=synchronous_enqueue_job)
@@ -194,9 +184,9 @@ def test_set_sha256_job_empty_file(enqueue_job_mock, create_with_upload,
     }])
     # Note: `call_action` bypasses authorization!
     # create 1st dataset
-    create_context = {'ignore_auth': False, 'user': user['name']}
-    dataset = make_dataset(create_context, owner_org, with_resource=False,
-                           activate=False)
+    create_context = {'ignore_auth': False,
+                      'user': user['name'], 'api_version': 3}
+    dataset = make_dataset(create_context, owner_org, activate=False)
     result = create_with_upload(
         b"", 'test.ini',
         url="upload",
